@@ -30,6 +30,7 @@
 #ifndef _conky_h_
 #define _conky_h_
 
+#include <cstddef>
 #define __STDC_FORMAT_MACROS
 
 #include "config.h"
@@ -157,6 +158,52 @@ char **get_templates(void);
  * needed by conky.c, linux.c and freebsd.c */
 enum { BATTERY_STATUS, BATTERY_TIME };
 
+namespace conky::info {
+
+// Don't guard enum values with #ifdef *_BUILD features; it will only make code
+// harder to maintain - size_t won't change in size.
+
+enum class display_session : std::size_t { unknown, x11, wayland };
+enum class window_manager : std::size_t {
+  unknown,
+
+  // X11
+  awesome,
+  bspwm,
+  compiz,
+  dde,  // Deepin
+  dwm,
+  enlightenment,
+  fluxbox,
+  herbstluftwm,
+  i3,
+  kwin,
+  marco,
+  metacity,
+  mutter,
+  openbox,
+  qtile,
+  xfwm,
+  windowmaker,
+
+  // Wayland (only)
+  hyprland,
+  river,
+  sway,
+  wayfire,
+
+  // Remember to update get_system_details when adding new ones!
+};
+
+struct system {
+  display_session session;
+
+  window_manager wm;
+  const char *wm_name;
+};
+
+}  // namespace conky::info
+
 struct information {
   unsigned int mask;
 
@@ -229,6 +276,11 @@ struct information {
   csr_config_t csr_config;
   csr_config_flags_t csr_config_flags;
 #endif /* defined(__APPLE__) && defined(__MACH__) */
+
+  /**
+   * @brief General information about the system currently running conky.
+   */
+  conky::info::system system;
 };
 
 class music_player_interval_setting
@@ -320,6 +372,20 @@ int spaced_print(char *, int, const char *, int, ...)
     __attribute__((format(printf, 3, 5)));
 extern int inotify_fd;
 
+template <
+    typename Iterable = std::initializer_list<conky::info::window_manager>>
+inline bool wm_is(const Iterable &values) {
+  // if constexpr (!ENABLE_RUNTIME_TWEAKS) { return false; }
+  // can't assume unknown isn't in the list...
+  for (const auto &wm : values) {
+    if (info.system.wm == wm) return true;
+  }
+  return false;
+}
+inline bool wm_is(conky::info::window_manager single) {
+  return info.system.wm == single;
+}
+
 /* defined in conky.c
  * evaluates 'text' and places the result in 'p' of max length 'p_max_size'
  */
