@@ -33,31 +33,35 @@
 #include "build.h"
 #include "config.h"
 #include "conky.h"
-#include "display-output.hh"
-#include "lua-config.hh"
+#include "output/display-output.hh"
+#include "lua/lua-config.hh"
 
 #ifdef BUILD_X11
-#include "x11.h"
+#include "output/x11.h"
 #endif /* BUILD_X11 */
 
 #ifdef BUILD_CURL
-#include "ccurl_thread.h"
+#include "data/network/ccurl_thread.h"
 #endif /* BUILD_CURL */
 
 #if defined(__linux__)
-#include "linux.h"
+#include "data/os/linux.h"
 #endif /* Linux */
 
 #if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
-#include "freebsd.h"
+#include "data/os/freebsd.h"
 #endif /* FreeBSD */
 
 #if defined(__NetBSD__)
-#include "netbsd.h"
+#include "data/os/netbsd.h"
 #endif /* NetBSD */
 
+#if defined(__OpenBSD__)
+#include "data/os/openbsd.h"
+#endif /* OpenBSD */
+
 #if defined(__HAIKU__)
-#include "haiku.h"
+#include "data/os/haiku.h"
 #endif /* Haiku */
 
 #ifdef BUILD_BUILTIN_CONFIG
@@ -282,9 +286,9 @@ static void print_help(const char *prog_name) {
          "   -p, --pause=SECS          pause for SECS seconds at startup "
          "before doing anything\n"
 #if defined(__linux__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || \
-    defined(__HAIKU__) || defined(__NetBSD__)
+    defined(__HAIKU__) || defined(__NetBSD__) || defined(__OpenBSD__)
          "   -U, --unique              only one conky process can be created\n"
-#endif /* Linux || FreeBSD || Haiku || NetBSD */
+#endif /* Linux || FreeBSD || Haiku || NetBSD || OpenBSD */
          , prog_name);
 }
 
@@ -368,23 +372,23 @@ int main(int argc, char **argv) {
         break;
 #endif /* BUILD_X11 */
 #if defined(__linux__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || \
-    defined(__HAIKU__) || defined(__NetBSD__)
+    defined(__HAIKU__) || defined(__NetBSD__) || defined(__OpenBSD__)
       case 'U':
         unique_process = true;
         break;
-#endif /* Linux || FreeBSD || Haiku || NetBSD */
+#endif /* Linux || FreeBSD || Haiku || NetBSD || OpenBSD */
       case '?':
         return EXIT_FAILURE;
     }
   }
 
 #if defined(__linux__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || \
-    defined(__HAIKU__) || defined(__NetBSD__)
+    defined(__HAIKU__) || defined(__NetBSD__) || defined(__OpenBSD__)
   if (unique_process && is_conky_already_running()) {
     NORM_ERR("already running");
     return 0;
   }
-#endif /* Linux || FreeBSD || Haiku */
+#endif /* Linux || FreeBSD || Haiku || NetBSD || OpenBSD */
 
   try {
     set_current_config();
