@@ -6,23 +6,21 @@ import {
   filterDesc,
 } from '../utils/doc-utils'
 import Docs from '../components/Docs'
-import { getSearchIndex, SearchIndex } from '../utils/search'
 
 export interface ConfigSettingsProps {
   config_settings: Documentation
-  searchIndex: SearchIndex
 }
 
 export default function ConfigSettings(props: ConfigSettingsProps) {
   return (
-    <Layout searchIndex={props.searchIndex}>
+    <Layout>
       <SEO
         title="Conky – Config settings"
         description="Conky configuration settings"
       />
-      <main className="w-full">
+      <main className="w-full pt-4">
         <div>
-          <h1 className="text-2xl" data-cy="page-heading">
+          <h1 className="text-2xl px-2 lg:px-4" data-cy="page-heading">
             Configuration settings
           </h1>
         </div>
@@ -34,7 +32,6 @@ export default function ConfigSettings(props: ConfigSettingsProps) {
 
 export async function getStaticProps() {
   const config_settings = filterDesc(getConfigSettings())
-  const searchIndex = getSearchIndex()
 
-  return { props: { config_settings, searchIndex } }
+  return { props: { config_settings } }
 }
